@@ -13,7 +13,7 @@
  * License
  * -------
  *
- * Copyright (c) 2005,2006,2007,2008 Russell Stuart.
+ * Copyright (c) 2005,2006,2007,2008,2009 Russell Stuart.
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -50,8 +50,8 @@ extern int errno;
 /*
  * Version info.
  */
-static char conspy_date[]	= "2008-02-01";
-static char conspy_version[]	= "1.5";
+static char conspy_date[]	= "2009-08-23";
+static char conspy_version[]	= "1.7";
 
 /*
  * VGA colour definitions, as found in a nibble in an attribute
@@ -179,8 +179,8 @@ static struct termios	old_termios;
 static int		opt_viewonly;
 static int  		tty_handle = -1;
 static char 		tty_name[20];
-static int  		vcsa_handle = -1;
-static char 		vcsa_name[20];
+static int  		device_handle = -1;
+static char 		device_name[20];
 
 /*
  * This array translates a VGA colour (defined above) to a
@@ -300,6 +300,10 @@ static void process_command_line(int argc, char** argv)
   int			opt;
   int			optindex;
   char			opts[(sizeof(options) / sizeof(*options))*2 + 1];
+  char 			vcc_name[sizeof(device_name)];
+  int			vcc_errno;
+  char 			vcsa_name[sizeof(device_name)];
+  int			vcsa_errno;
   char*			virtual_console;
 
   opt = 0;
@@ -335,21 +339,30 @@ static void process_command_line(int argc, char** argv)
    *  Verify we can open the devices.
    */
   strcpy(vcsa_name, "/dev/vcsa");
+  vcc_errno = 0;
   if (virtual_console != 0)
     strcat(vcsa_name, virtual_console);
-  vcsa_handle = open(vcsa_name, O_RDONLY);
-  if (vcsa_handle == -1 && errno == ENOENT)
+  strcpy(vcc_name, "/dev/vcc/a");
+  if (virtual_console != 0 && *virtual_console != '\0')
+    strcat(vcc_name, virtual_console);
+  else
+    strcat(vcc_name, "0");
+  strcpy(device_name, vcsa_name);
+  device_handle = open(vcsa_name, O_RDONLY);
+  vcsa_errno = errno;
+  if (device_handle == -1)
   {
-    strcpy(vcsa_name, "/dev/vcc/a");
-    if (virtual_console != 0 && *virtual_console != '\0')
-      strcat(vcsa_name, virtual_console);
-    else
-      strcat(vcsa_name, "0");
-    vcsa_handle = open(vcsa_name, O_RDONLY);
+    strcpy(device_name, vcc_name);
+    device_handle = open(vcc_name, O_RDONLY);
+    vcc_errno = errno;
   }
-  if (vcsa_handle == -1)
+  if (device_handle == -1)
   {
+    fprintf(stderr, "%s: could not open either the alternate device files.\n", me);
+    errno = vcsa_errno;
     perror(vcsa_name);
+    errno = vcc_errno;
+    perror(vcc_name);
     exit(1);
   }
   if (!opt_viewonly)
@@ -509,8 +522,8 @@ static void cleanup()
 {
   tcsetattr(0, TCSANOW, &old_termios);
   endwin();
-  if (vcsa_handle != -1)
-    close(vcsa_handle);
+  if (device_handle != -1)
+    close(device_handle);
   if (tty_handle != -1)
     close(tty_handle);
 }
@@ -562,11 +575,11 @@ static void conspy(int use_colour)
     /*
      * Read the video buffer.
      */
-    if (lseek(vcsa_handle, 0L, SEEK_SET) != 0L)
-      syserror(vcsa_name);
-    bytes_read = read(vcsa_handle, &vidbuf, sizeof(vidbuf));
+    if (lseek(device_handle, 0L, SEEK_SET) != 0L)
+      syserror(device_name);
+    bytes_read = read(device_handle, &vidbuf, sizeof(vidbuf));
     if (bytes_read == -1)
-      syserror(vcsa_name);
+      syserror(device_name);
     buffer_size = 4 +
 	vidbuf.vidbuf_lines * vidbuf.vidbuf_columns * sizeof(struct vidchar);
     if (buffer_size > sizeof(vidbuf))
